@@ -637,7 +637,12 @@ sync_orientation_items(GgvPostScriptView *ps_view)
 {
 	gint i;
 	gboolean orient_state;
-	
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (ps_view->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
+
 	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	for(i = 0; orientation_paths[i] != NULL; i++) {
 		if(i > 0)
@@ -657,6 +662,11 @@ sync_size_items(GgvPostScriptView *ps_view)
 	gint i;
 	gboolean size_state;
 	const gchar **paths;
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (ps_view->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
 
 	paths = size_paths;
 
@@ -839,11 +849,11 @@ verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
 		GtkWidget *chooser;
 
 		chooser = gtk_file_chooser_dialog_new(_("Select a file to save pages as"),
-						      GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
-						      GTK_FILE_CHOOSER_ACTION_SAVE,
-						      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						      GTK_STOCK_SAVE, GTK_RESPONSE_OK,
-						      NULL);
+											  GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
+											  GTK_FILE_CHOOSER_ACTION_SAVE,
+											  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+											  GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+											  NULL);
 		if(ps_view->priv->owner != NULL) {
 			bonobo_control_set_transient_for(ps_view->priv->owner,
 											 GTK_WINDOW(chooser), NULL);
@@ -853,10 +863,15 @@ verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
 		gtk_window_set_default_size(GTK_WINDOW(chooser), 600, 400);
 		if (ps_view->priv->save_path)
 			gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(chooser),
-						 		ps_view->priv->save_path);
-
-		if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_OK)
-			fname = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(chooser));
+													ps_view->priv->save_path);
+		
+		do {
+			fname = NULL;
+			if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_OK)
+				fname = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(chooser));
+			else
+				break;
+		} while(NULL == fname);
 
 		gtk_widget_destroy(chooser);
 
